#!/usr/bin/python3
# History:
# plot_temperatures.py  : executed script. Latest version to be copied to this name, so that crontab don't need to be updated
# plot_temperatures_01.py: initial version
# plot_temperatures_02.py: fixed graph scales
# plot_temperatures_03.py: debug problem with crontab print statements
# plot_temperatures_04.py: commented unusefull print statements


from matplotlib import pyplot as plt        #Must be installed manually
from matplotlib import dates
import datetime
import numpy as np
import linecache
import os

print('******************* Script start **********************')

commonpath='/home/pi/Temperature/'
csvpath=commonpath                          #containing csv data files to be processed
imgpath=commonpath+'jpg/'                   #where to put generated graphic files
processedpath=commonpath+'csv/'             #to move csv files after processing
suffix='_Temperatures'                      #Expected filename template: YYYY_MM_DD_Temperatures.log (ex: 2016_09_21_Temperatures.log)
csvextension='.log'
imgextension='.jpg'



def plot1file(fname,imgname):                               #Plots one file (fname) and generate 1 image (imgname)
    print('fname: ',fname)
    header=linecache.getline(fname, 1).split(';')                                   #gets column headers for legend
    print('header: ',header)
    datecsv=np.genfromtxt(fname, delimiter=';',skip_header=1,usecols=0,dtype=str)  #1st column = date
    timecsv=np.genfromtxt(fname, delimiter=';',skip_header=1,usecols=1,dtype=str)  #2nd column = time of day
    csv = np.genfromtxt(fname, delimiter=';',skip_header=1,usecols=(2,3,4,5))      #others columns are temp. series
#    print('datecsv: ',datecsv)
#    print('datecsv[0]: ',datecsv[0])
    filedate=datetime.datetime.strptime(datecsv[0],'%Y_%m_%d')
    print('filedate: ',filedate)
#    print('Date of the file: ',filedate.strftime('%A  %d/%m/%Y'))


    dtime=[]

    for i in range(len(timecsv)):               #gets x axis values in a vector
        dtime.append(datetime.datetime.strptime(timecsv[i],'%H:%M:%S'))

    hfmt = dates.DateFormatter('%H:%M')
    fig = plt.figure()
    ax1 = fig.add_subplot(111)
    ax1.xaxis.set_major_formatter(hfmt)
    ax1.plot(dtime,csv[:,1],label=header[3],color='red')    #Depart boiler
    ax1.plot(dtime,csv[:,2],label=header[4],color='orange') #Depart chauffage
    ax1.plot(dtime,csv[:,3],label=header[5],color='gray')   #Retour
    
    plt.ylim([0,50])
    #plt.plotfile(fname, cols=(1,2), delimiter=';',label='Ext')#,
    #plt.plotfile(fname, cols=(1,4), delimiter=';',label='Depart',newfig=False)
    ax1.legend(loc='lower right', numpoints = 3, fontsize='xx-small')
    ax1.set_ylabel('Température tuyaux °C')

    ax2=ax1.twinx()
    ax2.plot(dtime,csv[:,0],label=header[2],color='blue')   #Temperature ext
    ax2.set_ylabel('Température extérieure °C',color='blue')
    #ax2.legend(loc='upper right', numpoints = 3, fontsize='xx-small')
    for t2 in ax2.get_yticklabels():
        t2.set_color('blue')
    plt.title(filedate.strftime('PAC Ribaudes 11,%A  %d/%m/%Y'))
    plt.savefig(imgname)
    plt.close()
#    plt.show()     #Only neede for debug, otherwise blocks the execution until windows is colsed

print('This script cannot be lauched over SSH, unless -X option is used')
today=datetime.datetime.now()
todaystr=today.strftime('%Y_%m_%d')
print('today: ',todaystr)

filelist=[]
for file in os.listdir(csvpath):   #list only files having correct name template
    if file.endswith(suffix+csvextension) and len(file)==len(suffix)+len(csvextension)+10 :
        filelist.append(file[:-4])
print('filelist: ',filelist)


for file in filelist:
    plot1file(csvpath+file+csvextension,imgpath+file+imgextension)
    if not file.startswith(todaystr):                           #Avoid moving today's file (might not be complete)
        cmd='mv '+csvpath+file+csvextension+' '+processedpath
        print(cmd)
        os.system(cmd)                 #moves csv file not to process it anymore
print('****** THE END **********')
